/* eslint-disable react/no-unused-state */
import { Component } from "react";
import Taro from "@tarojs/taro";
import { View, ScrollView } from "@tarojs/components";
import { GetWeighOrderPageByOpenId } from '@/api/server'
import { goToPages, uShowToast, scrollToLower } from "@/utils/index";
import "./index.scss";
import moment from "moment";

export default class Index extends Component<
    any, { openId: any,  pageNo: number, pageSize: number, refresher: boolean, total: number, orderDetail: any[], payOrder: number, orderStatus: any }
> {
    constructor(props) {
        super(props);
        this.state = {
            orderDetail: [],
            openId: Taro.getStorageSync('openId'),
            pageNo: 1,
            pageSize: 5,
            refresher: false,
            total: 0,
            payOrder: 1,
            orderStatus: null
        };
    }
    componentDidMount() {
        this.getOrderData(true)
    }
    componentDidShow() {
        
    }
    onScrollToLower = () => {
        console.log('触底')
        scrollToLower(this.state.total, this.state.pageNo, this.state.pageSize).then((res) => {
            this.setState({ pageNo: res.pageNo }, () => this.getOrderData());
        });
    }
    onRefresherRefresh = () => {
        this.setState({ pageNo: 1 }, () => {
            this.getOrderData(true);
        })
    }
    getOrderData=  async (isFresher?: boolean | undefined)=> {
        let orderJson = {
            current: this.state.pageNo,
            pageSize: this.state.pageSize,
            states: this.state.orderStatus,
            openId: Taro.getStorageSync('openId'),
            //openId:'o4Uui64yhBNjfoyWpbCX7Q068VVs'
        }
        //获取订单信息
        const orderInf =await GetWeighOrderPageByOpenId(orderJson)
        if (isFresher) {
            this.setState({refresher: false, total: orderInf.data.total, orderDetail: orderInf.data.data || [], pageNo: orderInf.data.current})
          } else {
            this.setState({
              total: orderInf.data.total,
              orderDetail: this.state.orderDetail.concat(orderInf.data.data || []),
              pageNo: orderInf.data.current
            })
          }
        }

    changeOrderStatus(status: any) {
        this.setState({ orderStatus: status,pageNo:1 }, () => {
            this.getOrderData(true)
        })
    }

    render() {
        const { orderStatus, orderDetail } = this.state
        console.log('orderDetail', orderDetail);

        return (
            <View className='order-container'>
                <View className='order-navbar'>
                    <View className={orderStatus == null ? "order-navbar-item activity" : "order-navbar-item"} onClick={() => this.changeOrderStatus(null)}>
                        全部订单
                    </View>
                    <View className={orderStatus == 1 ? "order-navbar-item activity" : "order-navbar-item"} onClick={() => this.changeOrderStatus(1)}>
                        已完成
                    </View>
                </View>
                <ScrollView className='order-list-box' scrollY
                    refresherThreshold={100}
                    refresherEnabled
                    onRefresherPulling={() => this.setState({ refresher: true })}
                    refresherTriggered={this.state.refresher}
                    refresherBackground='#dedede'
                    onRefresherRefresh={this.onRefresherRefresh}
                    onScrollToLower={this.onScrollToLower}
                >
                    {orderDetail.map((item: any, index) => (
                        <View key={index} className='service-plate-card'>
                            <View className='service-plate-item'>
                                <View className='service-plate-left'>

                                </View>
                                <View className='service-plate-center'>
                                <View className='service-plate-name'>
                                        订单类型：{item.isFree?'免费':'收费'}
                                    </View>
                                    <View className='service-plate-name'>
                                        订单状态：{item.states > 0 ? <>已完成</> : <>未支付</>}
                                    </View>
                                    <View className='service-plate-desc'>
                                        订单时间：{moment(item.createAt).format('YYYY-MM-DD HH:mm:ss')}
                                    </View>
                                    <View className='service-plate-name'>
                                        订单编号：{item.id}
                                    </View>
                                </View>
                                {/* <View className='service-plate-right' onClick={() => {
                        goToPages(`/pages/tray/detail/index?orderid=${item.orderId}`)
                    }}
                    >
                        详情
                    </View> */}
                            </View>
                            <View className="service-plate-right">
                                <View className='order-detail-container'>
                                {item.diningPlateInfo?
                                        item.diningPlateInfo.map((dining)=>(
                                               
                                       
                                    <View className='food-card'>
                                        <>餐盘号:{dining.qrCode.split("HK")[1]}</>
                                        <View className='food-list-card'>
                                            <View className='foot-list-item' >
                                                <View className='food-item-name'>
                                                    商品名称
                                                </View>
                                                <View className='food-item-weight'>
                                                    重量(g)
                                                </View>
                                                <View className='food-item-price'>
                                                    单价
                                                </View>
                                                <View className='food-item-total'>
                                                    金额(元)
                                                </View>
                                            </View>
                                         
                                            {dining.goodsInfo ?
                                                dining.goodsInfo.map((item: any) => (
                                                    <View className='foot-list-item' >
                                                        <View className='food-item-name'>
                                                            {item.goodsName}
                                                        </View>
                                                        <View className='food-item-weight'>
                                                            {item.goodsWeight}
                                                        </View>
                                                        <View className='food-item-price'>
                                                            {item.price}
                                                        </View>
                                                        <View className='food-item-total'>
                                                            {item.totalAmount}
                                                        </View>
                                                    </View>
                                                ))
                                                : ""}

                                        </View>
                                    </View>
 )) :""   
}

                                </View>
                            </View>
                            <View className='oli-money'>
                                订单金额: ￥{item.totalAmount} </View>
                        </View>
                    ))}
                    <View>

                    </View>
                </ScrollView>
            </View>
        );
    }
}
